@@ -6,20 +6,16 @@ class BeginningOfStory(object):
         self.cls_name = cls_name
         self.name = name
         self.parent_name = None
-        self.same_object = None
 
     @property
     def story_name(self):
-        if self.parent_name is None:
-            return self.cls_name + "." + self.name
-        elif self.same_object:
-            return self.parent_name
-        else:
+        if self.parent_name is not None:
             return self.parent_name + " (" + self.cls_name + "." + self.name + ")"
+        else:
+            return self.cls_name + "." + self.name
 
-    def set_parent(self, parent_name, same_object):
+    def set_parent(self, parent_name):
         self.parent_name = parent_name
-        self.same_object = same_object
 
 
 class EndOfStory(object):
